'use client'
import React, {useContext} from 'react';
import {useRouter} from 'next/navigation';
import {AppContext} from '@/context/AppContext';
import {NavigationBtn} from '@/components/NavigationBtn';
import {ServerSelector} from '@/features/servers/components';
import {useSso} from '@/features/auth/hooks';
import {useSessionStorage} from '@/hooks';


export function Menu() {
    const {currentServer, currentVersion} = useContext(AppContext);
    const route = useRouter();
    const {isLoading, loginUrl, ssoSupported} = useSso();
    const {storeSsoState} = useSessionStorage();

    const handleLoad = () => {
        route.push(`/${currentVersion}?target_server=${currentServer}`);
    }

    const handleSsoLogin = () => {
        const url = new URL(loginUrl);
        const state = url.searchParams.get('state');
        storeSsoState(state);
        route.push(loginUrl);
    }

    const noServerAndVersionSelected = !currentVersion || !currentServer;

    return (
        <div className="w-180 mx-auto">
            <div className="flex flex-col items-start gap-4 sm:flex-row sm:items-center sm:justify-between">
                <ServerSelector />
                <NavigationBtn
                    value="Load"
                    disabled={noServerAndVersionSelected}
                    handleClick={handleLoad}
                    color="blue"
                    className="w-full mt-2 sm:w-auto"
                />
            </div>

            <div className="flex justify-center">
                <NavigationBtn
                    value="SSO Login"
                    disabled={isLoading || !ssoSupported}
                    handleClick={handleSsoLogin}
                    color="gray"
                    className="w-full mt-2 sm:w-60"
                />
            </div>
        </div>
    );
}
